/*
 *  Copyright (C) 2007  Thadeu Lima de Souza Cascardo <cascardo@minaslivre.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <glib.h>
#include <stdio.h>
#include <stdlib.h>
#include <depot.h>
#include <cabin.h>

int main (int argc, char **argv)
{
  GIOChannel *channel;
  GError *error;
  GIOStatus st;
  gchar *str;
  gsize len;
  DEPOT *db;
  int records;
  if (argc < 2)
    {
      g_critical ("No input file.");
      abort ();
    }
  error = NULL;
  channel = g_io_channel_new_file (argv[1], "r", &error);
  if (channel == NULL)
    {
      g_critical ("Could not open file: %s", error->message);
      g_error_free (error);
      abort ();
    }
  db = dpopen ("palestras", DP_OWRITER | DP_OCREAT, 0);
  if (db == NULL)
    {
      g_critical ("Could not create database.");
      abort ();
    }
  records = 0;
  for (st = g_io_channel_read_line (channel, &str, &len, NULL, &error);
       st == G_IO_STATUS_NORMAL;
       st = g_io_channel_read_line (channel, &str, &len, NULL, &error))
    {
      char **fields;
      int i;
      fields = g_strsplit (g_strchomp (str), ";", 0);
      if (fields != NULL || fields[0] != NULL)
        {
          for (i = 1; fields[i] != NULL; i+=3)
            {
	      if (fields[i+2] != NULL)
		{
		  CBMAP *map;
		  char *val;
		  int vlen;
		  map = cbmapopen ();
		  cbmapput (map, "id", -1, fields[0], -1, 0);
		  cbmapput (map, "palestra", -1, fields[i], -1, 0);
		  cbmapput (map, "palestrantes", -1, fields[i+1], -1, 0);
		  cbmapput (map, "email", -1, fields[i+2], -1, 0);
		  val = cbmapdump (map, &vlen);
		  cbmapclose (map);
		  dpput (db, (char *) &(records), sizeof records, val, vlen, DP_DOVER);
		  records++;
		  free (val);
		}
            }
        }
      g_strfreev (fields);
    }
  dpclose (db);
  g_io_channel_close (channel);
  return 0;
}
